package com.liang.dao;

import com.liang.entity.PrjAnnualBudgetRecord;
import com.liang.entity.PrjAnnualbudgetdetail;
import com.liang.entity.PrjBudget;
import com.liang.vo.PrjAnnualbudgetYzxqkVo;
import org.apache.ibatis.annotations.Param;
import org.springframework.data.domain.Pageable;

import java.math.BigDecimal;
import java.util.List;
import java.util.Map;

/**
 * 年度预算明细(PrjAnnualbudgetdetail)表数据库访问层
 *
 * @author makejava
 * @since 2023-05-19 21:59:13
 */
public interface PrjAnnualbudgetdetailDao {

    /**
     * 通过ID查询单条数据
     *
     * @param id 主键
     * @return 实例对象
     */
    PrjAnnualbudgetdetail queryById(Integer id);

    /**
     * 查询指定行数据
     *
     * @param prjAnnualbudgetdetail 查询条件
     * @param pageable              分页对象
     * @return 对象列表
     */
    List<PrjAnnualbudgetdetail> queryAllByLimit(PrjAnnualbudgetdetail prjAnnualbudgetdetail, @Param("pageable") Pageable pageable);

    /**
     * 统计总行数
     *
     * @param prjAnnualbudgetdetail 查询条件
     * @return 总行数
     */
    long count(PrjAnnualbudgetdetail prjAnnualbudgetdetail);

    /**
     * 新增数据
     *
     * @param prjAnnualbudgetdetail 实例对象
     * @return 影响行数
     */
    int insert(PrjAnnualbudgetdetail prjAnnualbudgetdetail);

    /**
     * 批量新增数据（MyBatis原生foreach方法）
     *
     * @param entities List<PrjBudget> 实例对象列表
     * @return 影响行数
     */
    int insertBatch(@Param("entities") List<PrjBudget> entities);

    /**
     * 批量新增或按主键更新数据（MyBatis原生foreach方法）
     *
     * @param entities List<PrjAnnualbudgetdetail> 实例对象列表
     * @return 影响行数
     * @throws org.springframework.jdbc.BadSqlGrammarException 入参是空List的时候会抛SQL语句错误的异常，请自行校验入参
     */
    int insertOrUpdateBatch(@Param("entities") List<PrjAnnualbudgetdetail> entities);

    /**
     * 修改数据
     *
     * @param prjAnnualbudgetdetail 实例对象
     * @return 影响行数
     */
    int update(PrjAnnualbudgetdetail prjAnnualbudgetdetail);

    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 影响行数
     */
    int deleteById(Integer id);

    /**
     * 获取年度预算列表
     *
     * @return
     */
    List<PrjAnnualbudgetdetail> getBudgetList(Integer nys);

    /**
     * 获取年度预算列表
     *
     * @return
     */
    List<PrjAnnualbudgetdetail> getFysqBudgetList(Integer nys);

    List<PrjAnnualbudgetdetail> getSubNode(@Param("nys") Integer nys, @Param("page") Integer page, @Param("limit") Integer limit, String mc);

    List<PrjAnnualbudgetdetail> getBz(Map map);
    /**
     * 批量删除年度预算明细
     *
     * @param nysList
     * @return
     */
    int batchDelete(List<Integer> nysList);

    int updateRWSYS(@Param("id") Integer id, @Param("DW") String DW);
    int updateWW(@Param("id") Integer id, @Param("DW") String DW);

    int updateWWYJZCF(@Param("id") Integer id, @Param("WWYJZCF") BigDecimal WWYJZCF);

    BigDecimal selectWWYJZCF_SX(@Param("id") Integer id, @Param("DW") String DW);

    BigDecimal getWw(@Param("id")Integer id,@Param("DW")String DW);
    BigDecimal selectXMZYS(Integer id);

    int updateXMZYS(@Param("id") Integer id, @Param("rwsys") BigDecimal rwsys);

    void updateNDYS(Integer id);

    void updateWWYJZCFSUM(Integer id);

    BigDecimal selectWWYJZCF_GW(@Param("id") Integer id, @Param("DW") String DW);

    BigDecimal selectXMZYS_SX(Integer rws);

    int updateRWSYS_SX(Integer rws);

    Integer getSubNodeCount(@Param("nys") Integer nys, @Param("page") Integer page, @Param("limit") Integer limit);

    List<PrjAnnualbudgetYzxqkVo> getYzxqk(@Param("nys") Integer nys);

    List<PrjAnnualbudgetYzxqkVo> getNf(@Param("nys")Integer nys);

    List<PrjAnnualbudgetdetail> listAllBudgetDetail(@Param("nys") Integer nys);

    List<PrjAnnualbudgetdetail> getXGJL(int xmid);

    Double getXMZYS(String id);

    void updateSPTGZT(@Param("nys") Integer id, @Param("fymc") String fymc, @Param("sptgzt") String xgjlxz);

    int updateXG(@Param("record") PrjAnnualBudgetRecord budget);

    List<PrjAnnualbudgetdetail> getSptgZt(Integer id);


    PrjAnnualbudgetdetail getByj(Map map);

    Double getKmXmzys(@Param("nys") Integer nys, @Param("fymc") String fymc);
}

